@@ -21,7 +21,7 @@
 # SOFTWARE.
 
 import networkx as nx  # type: ignore
-from aibolit.utils.ast import AST
+from aibolit.utils.ast_builder import build_ast
 from aibolit.utils.cohesiongraph import CohesionGraph
 
 
@@ -34,6 +34,6 @@ class LCOM4:
 
     def value(self, filename: str):
 
-        tree = AST(filename).value()
+        tree = build_ast(filename)
         G = self.coh.value(tree)
         return nx.number_connected_components(G)
