@@ -1,3 +1,4 @@
+from decimal import localcontext, ROUND_DOWN, Decimal
 from typing import List
 
 import numpy as np
@@ -98,11 +99,13 @@ class TwoFoldRankingModel(BaseEstimator):
         self.model = model
         self.model.fit(X, y.ravel(), logging_level='Silent')
 
-    def __get_pairs(self, item, th: float):
+    def __get_pairs(self, item, th: float, feature_importances=None):
         def sigmoid(x):
             return 1 / (1 + np.exp(-x))
 
-        pattern_importances = item * self.model.feature_importances_
+        if not feature_importances:
+            feature_importances = self.model.feature_importances_
+        pattern_importances = item * feature_importances
         # mask discards not significant patterns
         th_mask = (sigmoid(pattern_importances) <= th) + 0
         pattern_importances = pattern_importances * th_mask
@@ -112,7 +115,7 @@ class TwoFoldRankingModel(BaseEstimator):
     def __vstack_arrays(self, res):
         return np.vstack(res).T
 
-    def predict(self, X, quantity_func='log', th=1.0):
+    def calculate_score(self, X, quantity_func='log', th=1.0, feature_importances=None):
         """
         Args:
             X: np.array with shape (number of snippets, number of patterns) or
@@ -145,10 +148,90 @@ class TwoFoldRankingModel(BaseEstimator):
         for snippet in X:
             try:
                 item = quantity_funcs[quantity_func](snippet)
-                pairs = self.__vstack_arrays(self.__get_pairs(item, th))
+                pairs = self.__vstack_arrays(self.__get_pairs(item, th, feature_importances))
                 pairs = pairs[pairs[:, 0].argsort()]
                 ranked.append(pairs[:, 1].T.tolist()[::-1])
             except Exception:
+                import traceback
+                traceback.print_exc()
                 raise Exception("Unknown func")
 
         return (np.array(ranked), pairs[:, 0].T.tolist()[::-1])
+
+    def get_array(self, X, mask, i, incr):
+        """
+        Args:
+            X: np.array with shape (number of snippets, number of patterns).
+            mask: np.array with shape (number of snippets, number of patterns).
+            i: int, 0 <= i < number of patterns.
+            add: bool.
+        Returns:
+            X1: modified np.array with shape (number of snippets, number of patterns).
+        """
+
+        X1 = X.copy()
+        X1[:, i][mask[:, i]] += incr[mask[:, i]]
+
+        return X1
+
+    def get_minimum(self, c1, c2, c3):
+        """
+        Args:
+            c1, c2, c3: np.array with shape (number of snippets, ).
+        Returns:
+            c: np.array with shape (number of snippets, ) -
+            elemental minimum of 3 arrays.
+            number: np.array with shape (number of snippets, ) of
+            arrays' numbers with minimum elements.            .
+        """
+
+        c = np.vstack((c1, c2, c3))
+
+        return np.min(c, 0), np.argmin(c, 0)
+
+    def informative(self, X, scale=True, th=1.0):
+        """
+        Args:
+            X: np.array with shape (number of snippets, number of patterns + 1),
+            because last column is ncss
+        Returns:
+            ranked: np.array with shape (number of snippets, number of patterns)
+                of sorted patterns in non-increasing order for each snippet of
+                code.
+        """
+        X = X.copy()
+        X = np.expand_dims(X, axis=0)
+        # remember it, since we will use `log` function for non-normalized input value
+        X_old = X[:, :-1]
+
+        ncss = X[:, -1]
+        if scale:
+            X = X[:, :-1] / ncss.reshape(-1, 1)
+        else:
+            X = X[:, :-1]
+
+        k = X.shape[1]
+        complexity = self.model.predict(X)
+        mask = X > 0
+        importances = []
+        for i in range(k):
+            if X[0][i] == 0:
+                # do not need to predict if we have 0
+                importances.append((i, 0))
+                continue
+            complexity_minus = self.model.predict(self.get_array(X, mask, i, -1 / ncss))
+            if complexity_minus < complexity:
+                # complexity decreased
+                with localcontext() as ctx:
+                    ctx.rounding = ROUND_DOWN
+                    abs_diff = abs(complexity - complexity_minus)[0]
+                    diff = Decimal(abs_diff).quantize(Decimal('0.001'))
+                    diff = float(diff * 100)
+            else:
+                # complexity increased, we do not need such value, set to 0,
+                # cause we need only patterns when complexity decreased
+                diff = 0
+            importances.append((i, diff))
+
+        only_importances = list(np.array(importances).T[1])
+        return self.calculate_score(X_old[0], th=th, feature_importances=only_importances)
