@@ -1,5 +1,6 @@
 import javalang
-from aibolit.utils.ast import AST
+
+from aibolit.utils.ast_builder import build_ast
 
 
 class ImplementsMultiFinder:
@@ -8,5 +9,5 @@ class ImplementsMultiFinder:
         pass
 
     def value(self, filename: str):
-        tree = AST(filename).value().filter(javalang.tree.ClassDeclaration)
+        tree = build_ast(filename).filter(javalang.tree.ClassDeclaration)
         return [node._position.line for _, node in tree if node.implements and (len(node.implements) > 1)]
